summaryrefslogtreecommitdiff
path: root/jstests/sharding/sharding_rs2.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/sharding/sharding_rs2.js')
-rw-r--r--jstests/sharding/sharding_rs2.js6
1 files changed, 5 insertions, 1 deletions
diff --git a/jstests/sharding/sharding_rs2.js b/jstests/sharding/sharding_rs2.js
index 76b3f7e8f0e..6d27bc899f7 100644
--- a/jstests/sharding/sharding_rs2.js
+++ b/jstests/sharding/sharding_rs2.js
@@ -225,8 +225,12 @@ assert.eq(100, ts.count(), "E4");
assert.eq(100, ts.find().itcount(), "E5");
printjson(ts.find().batchSize(5).explain());
-// fsyncLock the secondaries
+// fsyncLock the secondaries and enable command logging on all the mongods.
+assert.commandWorked(
+ rs.getPrimary().adminCommand({setParameter: 1, logComponentVerbosity: {command: 2}}));
rs.getSecondaries().forEach(function(secondary) {
+ assert.commandWorked(
+ secondary.adminCommand({setParameter: 1, logComponentVerbosity: {command: 2}}));
assert.commandWorked(secondary.getDB("test").fsyncLock());
});